Index: src/main/java/geniusweb/profilesserver/websocket/GetProfileSocket.java
===================================================================
--- src/main/java/geniusweb/profilesserver/websocket/GetProfileSocket.java	(revision 13)
+++ src/main/java/geniusweb/profilesserver/websocket/GetProfileSocket.java	(revision 16)
@@ -28,5 +28,5 @@
 import geniusweb.profile.utilityspace.LinearAdditive;
 import geniusweb.profilesserver.Jackson;
-import geniusweb.profilesserver.ProfilesFactory;
+import geniusweb.profilesserver.ProfilesRepository;
 import geniusweb.profilesserver.events.ChangeEvent;
 import tudelft.utilities.immutablelist.FixedList;
@@ -38,5 +38,5 @@
  * and profiles. Every time something changes, a new list of domains and
  * profiles is sent. For each new websocket the server will create one of this
  * but they all share one {@link ProfilesFactory}.
  * 
  * <p>
@@ -80,9 +80,9 @@
 		};
 		sendupdatedProfile();
-		Profiles.factory.addListener(changeListener);
+		Profiles.repository.addListener(changeListener);
 	}
 
 	private void sendupdatedProfile() {
-		Profile newprof = Profiles.factory.getProfile(profilename);
+		Profile newprof = Profiles.repository.getProfile(profilename);
 		// notice, may be null if profile does not exist/was removed.
 		if (newprof == null ? prof != null : !newprof.equals(prof)) {
@@ -164,5 +164,5 @@
 	@OnClose
 	public void end() throws IOException {
-		Profiles.factory.removeListener(changeListener);
+		Profiles.repository.removeListener(changeListener);
 	}
 
@@ -38,5 +38,5 @@
  * and profiles. Every time something changes, a new list of domains and
  * profiles is sent. For each new websocket the server will create one of this
- * but they all share one {@link ProfilesFactory}.
+ * but they all share one {@link ProfilesRepository}.
  * 
  * <p>
Index: src/main/java/geniusweb/profilesserver/websocket/Profiles.java
===================================================================
--- src/main/java/geniusweb/profilesserver/websocket/Profiles.java	(revision 13)
+++ src/main/java/geniusweb/profilesserver/websocket/Profiles.java	(revision 16)
@@ -1,13 +1,14 @@
 package geniusweb.profilesserver.websocket;
 
-import geniusweb.profilesserver.AutoUpdatingProfilesFactory;
-import geniusweb.profilesserver.ProfilesFactory;
+import geniusweb.profilesserver.AutoUpdatingProfilesRepository;
+import geniusweb.profilesserver.ProfilesRepository;
 import tudelft.utilities.logging.ReportToLogger;
 
 /**
  * Just a shared copy of the profiles factory, for use with all websockets.
  * 
  */
 class Profiles {
-	public static final ProfilesFactory factory = new AutoUpdatingProfilesFactory(new ReportToLogger("profilesserver"));
+	public static final ProfilesRepository repository = new AutoUpdatingProfilesRepository(
+			new ReportToLogger("profilesserver"));
 }
@@ -1,13 +1,14 @@
 
 /**
- * Just a shared copy of the profiles factory, for use with all websockets.
+ * Just a shared copy of the profiles repository, for use with all websockets.
  * 
  */
Index: src/main/java/geniusweb/profilesserver/websocket/ProfilesListSocket.java
===================================================================
--- src/main/java/geniusweb/profilesserver/websocket/ProfilesListSocket.java	(revision 13)
+++ src/main/java/geniusweb/profilesserver/websocket/ProfilesListSocket.java	(revision 16)
@@ -25,5 +25,5 @@
 
 import geniusweb.profilesserver.Jackson;
-import geniusweb.profilesserver.ProfilesFactory;
+import geniusweb.profilesserver.ProfilesRepository;
 import geniusweb.profilesserver.events.ChangeEvent;
 import tudelft.utilities.listener.Listener;
@@ -35,5 +35,5 @@
  * and profiles. Every time something changes, a new list of domains and
  * profiles is sent. For each new websocket the server will create one of this
  * but they all share one {@link ProfilesFactory}.
  */
 @ServerEndpoint("/websocket/liststream")
@@ -71,5 +71,5 @@
 			}
 		};
-		Profiles.factory.addListener(changeListener);
+		Profiles.repository.addListener(changeListener);
 	}
 
@@ -90,6 +90,6 @@
 	private Map<URI, List<URI>> getDomainsProfiles() {
 		Map<URI, List<URI>> allprofiles = new HashMap<>();
-		for (String domain : Profiles.factory.getDomains()) {
-			List<URI> profiles = Profiles.factory.getProfiles(domain).stream()
+		for (String domain : Profiles.repository.getDomains()) {
+			List<URI> profiles = Profiles.repository.getProfiles(domain).stream()
 					.map(profile -> makeURI(domain, profile.getName()))
 					.collect(Collectors.toList());
@@ -153,5 +153,5 @@
 	@OnClose
 	public void end() throws IOException {
-		Profiles.factory.removeListener(changeListener);
+		Profiles.repository.removeListener(changeListener);
 	}
 
@@ -35,5 +35,5 @@
  * and profiles. Every time something changes, a new list of domains and
  * profiles is sent. For each new websocket the server will create one of this
- * but they all share one {@link ProfilesFactory}.
+ * but they all share one {@link ProfilesRepository}.
  */
 @ServerEndpoint("/websocket/liststream")
